function checkParametersMPT(obj)
%CHECKPARAMETERSMPT Check parameters for MPT toolbox
%
%   function checkParametersMPT(obj)
%       Checks for parameters in the H2T input object required for the
%       MPCController contructor of the MPT toolbox.
%
%   Details: help MPCControllers
%
%   Required:
%       - Sampling time
%       - Prediction horizon
%
%   Facultative:
%       - Input/state weights


    fprintf('\n------------------------------\n');
    fprintf('\nChecking options for MPT toolbox...\n');
    fprintf('\nFor details type:\n');
    fprintf('\thelp MPCController\n');
    fprintf('\nRequired:\n');

    % check sampling time
    if ss(obj.M).Ts <= 0 && obj.Ts <= 0
        fprintf('\t - Sampling time: MISSING!\n');
        fprintf('\t\t Use .setParameters(''SamplingTime'',Value)\n');
    else
        fprintf('\t - Sampling time: OK\n');
    end
    
    % check prediction horizon
    if isempty(obj.N)
        fprintf('\t - Prediction horizon: MISSING!\n');
        fprintf('\t\t Use .setParameters(''PredictionHorizon'',Value)\n');
    else
        fprintf('\t - Prediction horizon: OK\n');
    end

    fprintf('\nFacultative:\n');

    % check weights
    if isempty(obj.weights)
        fprintf('\t - Weights: MISSING!\n');
        fprintf('\t\t Use .setParameters(''InputWeights'',Value)\n');
        fprintf('\t\t     .setParameters(''StateWeights'',Value)\n');
        fprintf('\t\t and .setParameters(''OutputWeights'',Value)\n');
    else
        fprintf('\t - Weights: OK\n');
    end

    fprintf('\n------------------------------\n');
end

