

function ctrl = exportToMPT(obj)
    
    fprintf('\n------------------------------\n');
    fprintf('\nBuilding MPT controller...\n');
    

    % get the LSmodel
    M = obj.M;

    if ~isa(M,'LSmodel')
        error('The object must be of "LSmodel" class.');
    end

    % export to state space
    sys = ss(M);
    
    Ts = obj.Ts;

    % check if the system is continuous
    if sys.Ts<=0

        % convert to discrete-time domain    
        if isempty(Ts)
            error('Please, provide the sampling time to discretize the model.');
        end

        if ~isnumeric(Ts) || Ts<=0 || isinf(Ts)
            error('The sampling must be non-negative and finite-valued.');
        end    

        fprintf('\nConverting to discrete-time setting with sample time %f...\n',Ts);
        dsys = c2d(sys,Ts);
    else
        dsys = sys;
    end

    % import to MPT
    model = LTISystem(dsys);

    % set the input signal limits    
    [model.u.min, model.u.max] = obj.getLimits('Input');


    % set the output signal limits
    [model.y.min, model.y.max] = obj.getLimits('Output');

    % set the state signal limits
    [model.x.min, model.x.max] = obj.getLimits('State');

    % set input and state weights
    if isempty(obj.weights)
        fprintf('\nWeights non specified, setting default values...\n');
        obj.setParameters('InputWeights', 1, 'StateWeights', 1, 'OutputWeights', 1);
    end
    
    if isfield(obj.weights, 'u')
        model.u.penalty = Penalty(obj.weights.u,2);
    end
    if isfield(obj.weights, 'x')
        model.x.penalty = Penalty(obj.weights.x,2);
    end
    if isfield(obj.weights, 'y')
        model.y.penalty = Penalty(obj.weights.y,2);
    end

    % build controller
    ctrl = MPCController(model, obj.N);
    fprintf('\nSUCCESS\n');
    fprintf('\n------------------------------\n');

end