function checkParametersPNPMPC(obj)
%CHECKPARAMETERSPNPMPC Check parameters for PnPMPC toolbox
%
%   function checkParametersPNPMPC(obj)
%       Checks for parameters in the H2T input object required for the
%       createCtrlPnPMPC4lsmodel controller constructor of the PnPMPC toolbox.
%
%   See 
%       help createCtrlPnPMPC4lsmodel
%   for parameters details.
%
%   Required:
%       - Prediction horizon
%       - k
%       - Input types
%       - Output types


    fprintf('\n------------------------------\n');
    fprintf('\nChecking options for PnPMPC toolbox...\n');
    fprintf('\nFor details type:\n');
    fprintf('\thelp createCtrlPnPMPC4lsmodel\n');
    fprintf('\nRequired:\n');

    % check prediction horizon
    if isempty(obj.N)
        fprintf('\t - Prediction horizon: MISSING!\n');
        fprintf('\t\t Use .setParameters(''PredictionHorizon'',Value)\n');
    else
        fprintf('\t - Prediction horizon: OK\n');
    end
    
    % check k
    if isempty(obj.k)
        fprintf('\t - k parameter: MISSING!\n');
        fprintf('\t\t Use .setParameters(''k'',Value)\n');
    else
        fprintf('\t - k parameter: OK\n');
    end
    
    % check input types
    if isempty(obj.m)
        fprintf('\t - Input types: MISSING!\n');
        fprintf('\t\t Use .setParameters(''m'',Value)\n');
    else
        fprintf('\t - Input types: OK\n');
    end
    
    % check output types
    if isempty(obj.p)
        fprintf('\t - Output types: MISSING!\n');
        fprintf('\t\t Use .setParameters(''p'',Value)\n');
    else
        fprintf('\t - Output types: OK\n');
    end
    
    fprintf('\nFacultative:\n');

    % check sdpsettings
    if isempty(obj.sdpsettings)
        fprintf('\t - YALMIP sdpsettings: MISSING!\n');
        fprintf('\t\t Use .setParameters(''sdpsettings'',Value)\n');
        fprintf('\t\t (type ''help sdpsettings'' for infos)');
    else
        fprintf('\t - YALMIP sdpsettings: OK\n');
    end

    fprintf('\n------------------------------\n');
end

