function checkParametersWIDE(obj)
%CHECKPARAMETERSWIDE Check parameters for WIDE toolbox
%
%   function checkParametersWIDE(obj)
%       Checks for parameters in the H2T input object required for the
%       decLMI controller constructor of the WIDE toolbox.
%
%   Required:
%       - Coupling matrix
%
%   Facultative:
%       - Input/state weights
%       - Initial uncertainty set
%       - Packetloss probabilities


    fprintf('\n------------------------------\n');
    fprintf('\nChecking options for WIDE toolbox...\n');
    fprintf('\nFor details type:\n');
    fprintf('\thelp decLMI\n');
    fprintf('\nRequired:\n');

    % check coupling matrix
    if isempty(obj.Net)
        fprintf('\t - Coupling matrix: MISSING!\n');
        fprintf('\t\t Use .setParameters(''Net'',Value)\n');
    else
        fprintf('\t - Coupling matrix: OK\n');
    end

    fprintf('\nFacultative:\n');

    % check weights
    if isempty(obj.weights)
        fprintf('\t - Weights: MISSING!\n');
        fprintf('\t\t Use .setParameters(''InputWeights'',Value)\n');
        fprintf('\t\t and .setParameters(''StateWeights'',Value)\n');
    else
        fprintf('\t - Weights: OK\n');
    end
    
    % check initial uncertainty
    if isempty(obj.X0)
        fprintf('\t - Initial uncertainty: MISSING!\n');
        fprintf('\t\t Use .setAdditionalOptions(''X0'',Value)\n');
    else
        fprintf('\t - Initial uncertainty: OK\n');
    end
    
    % check packetloss probabilities
    if isempty(obj.Mc)
        fprintf('\t - Packetloss probabilities: MISSING!\n');
        fprintf('\t\t Use .setAdditionalOptions(''Mc'',Value)\n');
    else
        fprintf('\t - Packetloss probabilities: OK\n');
    end

    fprintf('\n------------------------------\n');
end

