function ctrl = exportToWIDE( obj )
%EXPORTTOWIDE Build the decentralized linear controller provided by decLMI
%   of WIDE toolbox, starting from an H2T object.

    fprintf('\n------------------------------\n');
    fprintf('\nBuilding WIDE controller...\n');
    
    % get state-space system
    sys = ss(obj.M);
    A = sys.A;
    B = sys.B;
    
    % get net matrix
    if isempty(obj.Net)
        error('Net matrix required');
    end   
    Net = obj.Net;
    
    % get weights
    if isempty(obj.weights)
        Qx = [];
        Qu = [];
    else
        Qx = obj.weights.x;
        Qu = obj.weights.u;
    end
    
    % get constraints
    [ul, uu] = obj.getLimits('Input');
    [xl, xu] = obj.getLimits('State');
    umax = abs(uu-ul)/2;
    xmax = abs(xu-xl)/2;
    
    % get initial uncertainty
    X0 = obj.X0;
    
    % get packetloss probabilities and build controller
    if isempty(obj.Mc)
        ctrl = decLMI(Net,A,B,Qx,Qu,X0,xmax,umax);
    else
        Mc = obj.Mc;
        ctrl = decLMI(Net,A,B,Qx,Qu,X0,xmax,umax,Mc);
    end
    
    fprintf('\nSUCCESS\n');
    fprintf('\n------------------------------\n');

end

